"""Common city aliases for quick access"""

COMMON_ALIASES = {
    # United States
    "nyc": "New York",
    "sf": "San Francisco",
    "la": "Los Angeles",
    "chicago": "Chicago",
    "dc": "Washington, DC",
    "miami": "Miami",
    "boston": "Boston",
    "seattle": "Seattle",
    "houston": "Houston",
    "vegas": "Las Vegas",
    
    # Europe
    "london": "London",
    "paris": "Paris",
    "bcn": "Barcelona",
    "ams": "Amsterdam",
    "rome": "Rome",
    "berlin": "Berlin",
    "mad": "Madrid",
    "lis": "Lisbon",
    "oslo": "Oslo",
    "cop": "Copenhagen",
    
    # Africa
    "dakar": "Dakar",
    "abidjan": "Abidjan",
    "accra": "Accra",
    "lagos": "Lagos",
    "cairo": "Cairo",
    "nairobi": "Nairobi",
    "casa": "Casablanca",
    "tunis": "Tunis",
    "algiers": "Algiers",
    "addis": "Addis Ababa",
    "kigali": "Kigali",
    "lome": "Lome",
    "bamako": "Bamako",
    "conakry": "Conakry",
    "djibouti": "Djibouti",
    "jburg": "Johannesburg",
    "capetown": "Cape Town",
    "durban": "Durban",
    "kinshasa": "Kinshasa",
    "luanda": "Luanda",
    
    # Asia
    "hk": "Hong Kong",
    "sg": "Singapore",
    "tokyo": "Tokyo",
    "seoul": "Seoul",
    "shanghai": "Shanghai",
    "beijing": "Beijing",
    "mumbai": "Mumbai",
    "delhi": "New Delhi",
    "dubai": "Dubai",
    "bkk": "Bangkok",
    
    # Australia & New Zealand
    "syd": "Sydney",
    "mel": "Melbourne",
    "bris": "Brisbane",
    "perth": "Perth",
    "auck": "Auckland",
    "wlg": "Wellington",
    
    # Canada
    "van": "Vancouver",
    "tor": "Toronto",
    "mtl": "Montreal",
    "cal": "Calgary",
    "ott": "Ottawa",
    
    # Latin America
    "cdmx": "Mexico City",
    "rio": "Rio de Janeiro",
    "sp": "Sao Paulo",
    "bsas": "Buenos Aires",
    "lima": "Lima",
    "stgo": "Santiago",
    "bog": "Bogota"
} 